@@ -3,7 +3,7 @@ package App::genpw::wordlist;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-21'; # DATE
 our $DIST = 'App-genpw-wordlist'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -60,16 +60,19 @@ sub genpw {
     my $wordlists = delete($args{wordlists}) // ['EN::Enable'];
     my $patterns = delete($args{patterns}) // $default_patterns;
 
-    my $res = App::wordlist::wordlist(
-        (wordlists => $wordlists) x !!defined($wordlists),
-        random => 1,
-    );
-    return $res unless $res->[0] == 200;
+    my $res;
+    unless ($args{action} && $args{action} eq 'list-patterns') {
+        $res = App::wordlist::wordlist(
+            (wordlists => $wordlists) x !!defined($wordlists),
+            random => 1,
+        );
+        return $res unless $res->[0] == 200;
+    }
 
     App::genpw::genpw(
         %args,
         patterns => $patterns,
-        _words => $res->[2],
+        ($res ? (_words => $res->[2]) : ()),
     );
 }
 
@@ -88,7 +91,7 @@ App::genpw::wordlist - Generate password with words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.006 of App::genpw::wordlist (from Perl distribution App-genpw-wordlist), released on 2020-05-21.
+This document describes version 0.007 of App::genpw::wordlist (from Perl distribution App-genpw-wordlist), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -123,6 +126,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<action> => I<str> (default: "gen")
+
 =item * B<case> => I<str> (default: "default")
 
 Force casing.
